<?php
/*
	Module Name: Skeleton
	Module URI: http://www.ecartservice.net/03082009/writing-your-own-prestashop-module-part-5/
	Description: A template to use as the basis for writing Prestashop modules
	Version: 0.1.0
	Author: Paul Campbell
	Author URI: http://www.ecartservice.net/
	
	Copyright 2009, paul r campbell (pcampbell@ecartservice.net)

	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.
	
	This copyright notice  and licence should be retained in all modules based on this framework.
	This does not affect your rights to assert copyright over your own original work.
*/

class Skeleton extends Module
{
	private $_html = '';
	private $_postErrors = array();
	
	function __construct()
	{
		$this->name = 'skeleton';		
		parent::__construct();
				
		$this->tab = 'eCartService.net Tutorials';
		$this->version = '0.1.0';
		$this->displayName = $this->l('A Prestashop template Module by eCartService.net');
		$this->description = $this->l('Use this code as the basis for your own modules');			
	}

	public function install()
	{
		parent::install();
		
		if (!$this->registerHook('leftColumn'))
			return false;
			
		// Set some defaults
		Configuration::updateValue($this->name.'_message', 'Message goes here');
		Configuration::updateValue($this->name.'_checkbox', 'true');
		Configuration::updateValue($this->name.'_dropdown', 'none');
		Configuration::updateValue($this->name.'_textarea', 'A longer bit of text, perhaps a description, may need more space than an input control can provide. HTML is tricky, since it will be rendered as-is unless you convert to entities before display.');
		Configuration::updateValue($this->name.'_radio', 'less');
	}

	private function _postValidation()
	{
		if (!Validate::isCleanHtml(Tools::getValue('our_message')))
			$this->_postErrors[] = $this->l('The message you entered was not allowed, sorry');
	}
	
	private function _postProcess()
	{
		Configuration::updateValue($this->name.'_message', Tools::getValue('our_message'), true);
		Configuration::updateValue($this->name.'_checkbox', (Tools::getValue('our_checkbox') ? 'true' : 'false'));
		Configuration::updateValue($this->name.'_dropdown', Tools::getValue('our_dropdown'));
		Configuration::updateValue($this->name.'_textarea', Tools::getValue('our_textarea')); // html in here gets tricky ;)
		Configuration::updateValue($this->name.'_radio', Tools::getValue('our_radio'));
		
		$this->_html .= '<div class="conf confirm">'.$this->l('Settings updated').'</div>';
	}
	
	public function getContent()
	{
		$this->_html .= '<h2>'.$this->displayName.'</h2>';
		
		if (Tools::isSubmit('submit'))
		{			
			$this->_postValidation();
			
			if (!sizeof($this->_postErrors))
				$this->_postProcess();
			else
			{
				foreach ($this->_postErrors AS $err)
				{
					$this->_html .= '<div class="alert error">'.$err.'</div>';
				}
			}
		}
		
		$this->_displayForm();
		
		return $this->_html;
	}
	
	private function _displayForm()
	{
		$this->_html .= '
		<form action="'.$_SERVER['REQUEST_URI'].'" method="post">
			<fieldset>
				<legend><img src="../img/admin/cog.gif" alt="" class="middle" />'.$this->l('Settings').'</legend>
				<label>'.$this->l('Message to the world').'</label>
				<div class="margin-form">
					<input type="text" name="our_message" value="'.Tools::getValue('our_message', Configuration::get($this->name.'_message')).'"/>
					<p class="clear">'.$this->l('A message which will display as a block heading in the example code').'</p>
				</div>
				<label>'.$this->l('Textarea').'</label>
				<div class="margin-form">
					<textarea rows="6" cols="80" name="our_textarea" >'.Tools::getValue('our_textarea', Configuration::get($this->name.'_textarea')).'</textarea>
					<p class="clear">'.$this->l('A block of text').'</p>
				</div>
				<label>'.$this->l('Drop-Down').'</label>
				<div class="margin-form">
					<select name = "our_dropdown">
					<option value="none"'.(Tools::getValue('our_dropdown', Configuration::get($this->name.'_dropdown')) == "none" ? ' SELECTED' : '').' >None</option>
					<option value="more"'.(Tools::getValue('our_dropdown', Configuration::get($this->name.'_dropdown')) == "more" ? ' SELECTED' : '').' >More</option>
					<option value="less"'.(Tools::getValue('our_dropdown', Configuration::get($this->name.'_dropdown')) == "less" ? ' SELECTED' : '').' >Less</option>
					</select>
					<p class="clear">'.$this->l('A list of options').'</p>
				</div>
				<label>'.$this->l('A checkbox').'</label>
				<div class="margin-form">
					<input type="checkbox" name="our_checkbox" value="'.(Tools::getValue('our_checkbox', Configuration::get($this->name.'_checkbox')) ? "true" : "false").'"' .
					(Tools::getValue('our_checkbox', Configuration::get($this->name.'_checkbox')) == "true" ? ' checked="checked"' : '') . ' />
					<p class="clear">'.$this->l('A true or false checkbox').'</p>
				</div>
				<label>'.$this->l('Radio buttons').'</label>
				<div class="margin-form">
					<input type="radio" name="our_radio" value="none"'.(Tools::getValue('our_radio', Configuration::get($this->name.'_radio')) == "none" ? ' checked="checked"' : '').' >None</option>
					<input type="radio" name="our_radio" value="more"'.(Tools::getValue('our_radio', Configuration::get($this->name.'_radio')) == "more" ? ' checked="checked"' : '').' >More</option>
					<input type="radio" name="our_radio" value="less"'.(Tools::getValue('our_radio', Configuration::get($this->name.'_radio')) == "less" ? ' checked="checked"' : '').' >Less</option>
					<p class="clear">'.$this->l('3-way radio buttons').'</p>
				</div>
			<input type="submit" name="submit" value="'.$this->l('Update').'" class="button" />
			</fieldset>			
		</form>';	
	}
		
	public function hookLeftColumn()
	{
		return '<div class="block"><h4>'. Configuration::get($this->name.'_message') . '</h4></div>';
	}
	
	function hookRightColumn($params)
	{
		return $this->hookLeftColumn($params);
	}
	
	function hookTop($params)
	{
		return $this->hookLeftColumn($params);
	}
	
	function hookHome($params)
	{
		return $this->hookLeftColumn($params);
	}
	
	function hookFooter($params)
	{
		return $this->hookLeftColumn($params);
	}
	
}
// End of: skeleton.php
